@@ -1,9 +1,10 @@
 # App::hopen::G::FilesCmd - Cmd that outputs a list of files.
 package App::hopen::G::FilesCmd;
 use Data::Hopen;
+use strict; use warnings;
 use Data::Hopen::Base;
 
-our $VERSION = '0.000010';
+our $VERSION = '0.000015'; # TRIAL
 
 use parent 'App::hopen::G::Cmd';
 use Class::Tiny {
@@ -16,13 +17,20 @@ use App::hopen::Asset;
 
 =head1 NAME
 
-Data::Hopen::G::FilesCmd - Cmd that holds a list of files.
+App::hopen::G::FilesCmd - Cmd that holds a list of files.
 
 =head1 SYNOPSIS
 
-    my $node = Data::Hopen::G::FilesCmd(files=>['foo.c'], name=>'foo node');
+    my $node = App::hopen::G::FilesCmd(files=>['foo.c'], name=>'foo node');
 
-Used by L<Data::Hopen::H/files>.
+Used by L<App::hopen::H/files>.
+
+=head1 ATTRIBUTES
+
+=head2 files
+
+The files that this Cmd outputs.  Intended to be L<App::hopen::Util::BasedPath>
+instances.
 
 =head1 FUNCTIONS
 
@@ -34,12 +42,12 @@ Used by L<Data::Hopen::H/files>.
 
 Create L<App::hopen::Asset>s for the listed files and add them to the
 generator's asset graph.
-See L<Data::Hopen::Conventions/INTERNALS>.
+See L<App::hopen::Conventions/INTERNALS>.
 
 =cut
 
 sub _run {
-    my ($self, %args) = getparameters('self', [qw(phase visitor ; *)], @_);
+    my ($self, %args) = getparameters('self', [qw(visitor ; *)], @_);
 
     my @assets = $self->make(@{$self->files});
     $args{visitor}->asset($_) foreach @assets;
