@@ -1,18 +1,14 @@
 # App::hopen::T::Gnu - GNU toolset
 package App::hopen::T::Gnu;
 use Data::Hopen;
+use strict; use warnings;
 use Data::Hopen::Base;
 
-our $VERSION = '0.000010';
-
-#use parent 'Data::Hopen::TODO';
-#use Class::Tiny qw(TODO);
-
-# Docs {{{1
+our $VERSION = '0.000015'; # TRIAL
 
 =head1 NAME
 
-Data::Hopen::T::Gnu - GNU toolset for hopen
+App::hopen::T::Gnu - GNU toolset for hopen
 
 =head1 SYNOPSIS
 
@@ -21,8 +17,6 @@ linker that will accept GNU ld(1) options.
 
 =cut
 
-# }}}1
-
 1;
 __END__
 # vi: set fdm=marker: #
